PyCatastro
==========

Python library to comunicate with Spanish Catastro

All the consult services are implemented, for an auccurate description of the return format check
http://www.catastro.meh.es/ws/Webservices_Libres.pdf